@@ -123,6 +123,10 @@ enum connect_state
 	CONN_TEMPORARY
 };
 
+#define NCP_CONN_INVALID	0
+#define NCP_CONN_PERMANENT	1
+#define NCP_CONN_TEMPORARY	2
+
 #define NCPFS_MAX_CFG_USERNAME	256
 
 struct ncp_conn
@@ -199,6 +203,43 @@ void ncp_add_mem(struct ncp_conn*, const void*, int);
 long ncp_request(struct ncp_conn*, int);
 void ncp_unlock_conn(struct ncp_conn*);
 char* ncp_reply_data(struct ncp_conn*, int);
+
+#define ncp_printf printf
+
+static inline void assert_conn_locked(struct ncp_conn *conn) {
+        if (conn->lock == 0) {
+                ncp_printf("ncpfs: conn not locked!\n");
+        }
+}
+
+static inline void ncp_add_byte(struct ncp_conn *conn, byte x) {
+        assert_conn_locked(conn);
+        BSET(conn->packet, conn->current_size, x);
+        conn->current_size += 1;
+        return;
+}
+
+static inline void ncp_add_word_lh(struct ncp_conn *conn, word x) {
+        assert_conn_locked(conn);
+        WSET_LH(conn->packet, conn->current_size, x);
+        conn->current_size += 2;
+        return;
+}
+
+static inline void ncp_add_word_hl(struct ncp_conn *conn, word x) {
+        assert_conn_locked(conn);
+        WSET_HL(conn->packet, conn->current_size, x);
+        conn->current_size += 2;
+        return;
+}
+
+static inline void ncp_add_dword_lh(struct ncp_conn *conn, dword x) {
+        assert_conn_locked(conn);
+        DSET_LH(conn->packet, conn->current_size, x);
+        conn->current_size += 4;
+        return;
+}
+
 #endif
 
 /* ncp_initialize is the main entry point for user programs which want
@@ -789,6 +830,9 @@ ncp_ns_get_full_name(struct ncp_conn* conn, __u8 src_ns, __u8 dst_ns,
 		     const unsigned char* encpath, size_t pathlen,
 	             char* name, size_t maxnamelen);
 
+int
+ncp_get_conn_type(struct ncp_conn* conn);
+
 #endif /* not __MAKE_SULIB__ */
 
 #ifdef SIGNATURES
