@@ -16,8 +16,11 @@ int
 main(int argc, char **argv)
 {
 	struct ncp_conn *conn;
-	__u8 conn_list[256] = {0,};
+	__u8 conn_list[256] =
+	{0,};
 	int no_conn;
+	int conn_list2[256];
+	int i;
 
 	char *message = NULL;
 	char *user = NULL;
@@ -25,17 +28,15 @@ main(int argc, char **argv)
 
 	if ((conn = ncp_initialize(&argc, argv, 1, &err)) == NULL)
 	{
-		com_err(argv[0], err, "in ncp_initialize");
+		com_err(argv[0], err, "when initializing");
 		exit(1);
 	}
-
 	if (argc != 3)
 	{
 		fprintf(stderr, "usage: %s [options] user message\n", argv[0]);
 		ncp_close(conn);
 		exit(1);
 	}
-
 	user = argv[1];
 	message = argv[2];
 
@@ -46,19 +47,25 @@ main(int argc, char **argv)
 		ncp_close(conn);
 		exit(1);
 	}
-
 	if (no_conn == 0)
 	{
 		fprintf(stderr, "No connection found for %s\n", user);
 		ncp_close(conn);
 		exit(1);
 	}
-
-	if ((err = ncp_send_broadcast(conn, no_conn, conn_list, message)) != 0)
+	for (i=0; i<no_conn; i++)
+		conn_list2[i] = conn_list[i];
+	if ((err = ncp_send_broadcast2(conn, no_conn, conn_list2, message)) != 0)
 	{
-		com_err(argv[0], err, "in send_broadcast");
-		ncp_close(conn);
-		exit(1);
+		/* NetWare 2.x returns error code 0x89FB - function not implemented */
+		if (conn->completion == 0xFB)
+			err = ncp_send_broadcast(conn, no_conn, conn_list, message);
+		if (err)
+		{
+			com_err(argv[0], err, "in send_broadcast");
+			ncp_close(conn);
+			exit(1);
+		}
 	}
 	ncp_close(conn);
 	return 0;
